==> arquillian-container-test-impl-base-1.1.12.Final-sources.jar: org/jboss/arquillian/container/test/impl/ClientTestInstanceEnricher.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl;

import org.jboss.arquillian.container.spi.Container;
import org.jboss.arquillian.container.spi.client.deployment.Deployment;
import org.jboss.arquillian.core.api.Instance;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.test.impl.TestInstanceEnricher;
import org.jboss.arquillian.test.spi.event.suite.Before;

/**
 * ClientTestInstanceEnricher, a TestInstanceEnricher that is aware of RunModes.
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ClientTestInstanceEnricher extends TestInstanceEnricher
{
   @Inject
   private Instance<Deployment> deployment;

   @Inject
   private Instance<Container> container;

   @Override
   public void enrich(Before event) throws Exception
   {
      boolean runAsClient = RunModeUtils.isRunAsClient(
            this.deployment.get(),
            event.getTestClass(),
            event.getTestMethod());
      
      if(runAsClient || RunModeUtils.isLocalContainer(container.get()))
      {
         super.enrich(event);
      }
   }
}

==> arquillian-container-test-impl-base-1.4.0.Final-sources.jar: org/jboss/arquillian/container/test/impl/ClientTestInstanceEnricher.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.container.test.impl;

import org.jboss.arquillian.container.spi.Container;
import org.jboss.arquillian.container.spi.client.deployment.Deployment;
import org.jboss.arquillian.core.api.Instance;
import org.jboss.arquillian.core.api.annotation.Inject;
import org.jboss.arquillian.test.impl.TestInstanceEnricher;
import org.jboss.arquillian.test.spi.event.suite.Before;

/**
 * ClientTestInstanceEnricher, a TestInstanceEnricher that is aware of RunModes.
 *
 * @author <a href="mailto:aslak@redhat.com">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ClientTestInstanceEnricher extends TestInstanceEnricher {
    @Inject
    private Instance<Deployment> deployment;

    @Inject
    private Instance<Container> container;

    @Override
    public void enrich(Before event) throws Exception {
        boolean runAsClient = RunModeUtils.isRunAsClient(
            this.deployment.get(),
            event.getTestClass(),
            event.getTestMethod());

        if (runAsClient || RunModeUtils.isLocalContainer(container.get())) {
            super.enrich(event);
        }
    }
}
